/********************************************************************************
** Form generated from reading UI file 'addshortcutdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDSHORTCUTDIALOG_H
#define UI_ADDSHORTCUTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <fcitxqti18nhelper.h>
#include "fcitxqtkeysequencewidget.h"

QT_BEGIN_NAMESPACE

class Ui_AddShortcutDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *inputModeLabel_;
    QComboBox *inputModeComboBox_;
    QLabel *commandLabel_;
    QComboBox *commandComboBox_;
    fcitx::FcitxQtKeySequenceWidget *keyButton_;
    QLabel *keyLabel_;
    QDialogButtonBox *buttonBox_;

    void setupUi(QDialog *AddShortcutDialog)
    {
        if (AddShortcutDialog->objectName().isEmpty())
            AddShortcutDialog->setObjectName("AddShortcutDialog");
        AddShortcutDialog->resize(356, 148);
        verticalLayout = new QVBoxLayout(AddShortcutDialog);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        inputModeLabel_ = new QLabel(AddShortcutDialog);
        inputModeLabel_->setObjectName("inputModeLabel_");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, inputModeLabel_);

        inputModeComboBox_ = new QComboBox(AddShortcutDialog);
        inputModeComboBox_->setObjectName("inputModeComboBox_");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(inputModeComboBox_->sizePolicy().hasHeightForWidth());
        inputModeComboBox_->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, inputModeComboBox_);

        commandLabel_ = new QLabel(AddShortcutDialog);
        commandLabel_->setObjectName("commandLabel_");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, commandLabel_);

        commandComboBox_ = new QComboBox(AddShortcutDialog);
        commandComboBox_->setObjectName("commandComboBox_");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, commandComboBox_);

        keyButton_ = new fcitx::FcitxQtKeySequenceWidget(AddShortcutDialog);
        keyButton_->setObjectName("keyButton_");
        keyButton_->setMinimumSize(QSize(0, 0));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, keyButton_);

        keyLabel_ = new QLabel(AddShortcutDialog);
        keyLabel_->setObjectName("keyLabel_");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(keyLabel_->sizePolicy().hasHeightForWidth());
        keyLabel_->setSizePolicy(sizePolicy1);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, keyLabel_);


        verticalLayout->addLayout(formLayout);

        buttonBox_ = new QDialogButtonBox(AddShortcutDialog);
        buttonBox_->setObjectName("buttonBox_");
        buttonBox_->setOrientation(Qt::Horizontal);
        buttonBox_->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox_);

#if QT_CONFIG(shortcut)
        inputModeLabel_->setBuddy(inputModeComboBox_);
        commandLabel_->setBuddy(commandComboBox_);
        keyLabel_->setBuddy(keyButton_);
#endif // QT_CONFIG(shortcut)

        retranslateUi(AddShortcutDialog);
        QObject::connect(buttonBox_, &QDialogButtonBox::accepted, AddShortcutDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox_, &QDialogButtonBox::rejected, AddShortcutDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AddShortcutDialog);
    } // setupUi

    void retranslateUi(QDialog *AddShortcutDialog)
    {
        AddShortcutDialog->setWindowTitle(fcitx::tr2fcitx("Dialog", nullptr));
        inputModeLabel_->setText(fcitx::tr2fcitx("&Input Mode:", nullptr));
        commandLabel_->setText(fcitx::tr2fcitx("&Command:", nullptr));
        keyLabel_->setText(fcitx::tr2fcitx("&Key:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AddShortcutDialog: public Ui_AddShortcutDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADDSHORTCUTDIALOG_H
