/********************************************************************************
** Form generated from reading UI file 'adddictdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDDICTDIALOG_H
#define UI_ADDDICTDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <fcitxqti18nhelper.h>

QT_BEGIN_NAMESPACE

class Ui_AddDictDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *typeLabel_;
    QComboBox *typeComboBox_;
    QLabel *pathLabel_;
    QHBoxLayout *horizontalLayout;
    QLineEdit *urlLineEdit_;
    QPushButton *browseButton_;
    QDialogButtonBox *buttonBox_;

    void setupUi(QDialog *AddDictDialog)
    {
        if (AddDictDialog->objectName().isEmpty())
            AddDictDialog->setObjectName("AddDictDialog");
        AddDictDialog->resize(356, 126);
        verticalLayout = new QVBoxLayout(AddDictDialog);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        typeLabel_ = new QLabel(AddDictDialog);
        typeLabel_->setObjectName("typeLabel_");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, typeLabel_);

        typeComboBox_ = new QComboBox(AddDictDialog);
        typeComboBox_->setObjectName("typeComboBox_");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(typeComboBox_->sizePolicy().hasHeightForWidth());
        typeComboBox_->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, typeComboBox_);

        pathLabel_ = new QLabel(AddDictDialog);
        pathLabel_->setObjectName("pathLabel_");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, pathLabel_);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        urlLineEdit_ = new QLineEdit(AddDictDialog);
        urlLineEdit_->setObjectName("urlLineEdit_");

        horizontalLayout->addWidget(urlLineEdit_);

        browseButton_ = new QPushButton(AddDictDialog);
        browseButton_->setObjectName("browseButton_");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("document-open");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        browseButton_->setIcon(icon);

        horizontalLayout->addWidget(browseButton_);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout);


        verticalLayout->addLayout(formLayout);

        buttonBox_ = new QDialogButtonBox(AddDictDialog);
        buttonBox_->setObjectName("buttonBox_");
        buttonBox_->setOrientation(Qt::Horizontal);
        buttonBox_->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox_);

#if QT_CONFIG(shortcut)
        typeLabel_->setBuddy(typeComboBox_);
        pathLabel_->setBuddy(urlLineEdit_);
#endif // QT_CONFIG(shortcut)

        retranslateUi(AddDictDialog);
        QObject::connect(buttonBox_, &QDialogButtonBox::accepted, AddDictDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox_, &QDialogButtonBox::rejected, AddDictDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AddDictDialog);
    } // setupUi

    void retranslateUi(QDialog *AddDictDialog)
    {
        AddDictDialog->setWindowTitle(fcitx::tr2fcitx("Dialog", nullptr));
        typeLabel_->setText(fcitx::tr2fcitx("&Type:", nullptr));
        pathLabel_->setText(fcitx::tr2fcitx("&Path:", nullptr));
        browseButton_->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class AddDictDialog: public Ui_AddDictDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADDDICTDIALOG_H
