/********************************************************************************
** Form generated from reading UI file 'dictwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DICTWIDGET_H
#define UI_DICTWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <fcitxqti18nhelper.h>

QT_BEGIN_NAMESPACE

class Ui_KkcDictWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QListView *dictionaryView_;
    QVBoxLayout *verticalLayout_2;
    QPushButton *addDictButton_;
    QPushButton *removeDictButton_;
    QPushButton *moveUpDictButton_;
    QPushButton *moveDownDictButton_;
    QPushButton *defaultDictButton_;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *KkcDictWidget)
    {
        if (KkcDictWidget->objectName().isEmpty())
            KkcDictWidget->setObjectName("KkcDictWidget");
        KkcDictWidget->resize(355, 247);
        horizontalLayout = new QHBoxLayout(KkcDictWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        dictionaryView_ = new QListView(KkcDictWidget);
        dictionaryView_->setObjectName("dictionaryView_");

        horizontalLayout->addWidget(dictionaryView_);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        addDictButton_ = new QPushButton(KkcDictWidget);
        addDictButton_->setObjectName("addDictButton_");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        addDictButton_->setIcon(icon);

        verticalLayout_2->addWidget(addDictButton_);

        removeDictButton_ = new QPushButton(KkcDictWidget);
        removeDictButton_->setObjectName("removeDictButton_");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        removeDictButton_->setIcon(icon1);

        verticalLayout_2->addWidget(removeDictButton_);

        moveUpDictButton_ = new QPushButton(KkcDictWidget);
        moveUpDictButton_->setObjectName("moveUpDictButton_");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("go-up");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        moveUpDictButton_->setIcon(icon2);

        verticalLayout_2->addWidget(moveUpDictButton_);

        moveDownDictButton_ = new QPushButton(KkcDictWidget);
        moveDownDictButton_->setObjectName("moveDownDictButton_");
        QIcon icon3;
        iconThemeName = QString::fromUtf8("go-down");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        moveDownDictButton_->setIcon(icon3);

        verticalLayout_2->addWidget(moveDownDictButton_);

        defaultDictButton_ = new QPushButton(KkcDictWidget);
        defaultDictButton_->setObjectName("defaultDictButton_");
        QIcon icon4;
        iconThemeName = QString::fromUtf8("document-revert");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        defaultDictButton_->setIcon(icon4);

        verticalLayout_2->addWidget(defaultDictButton_);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);


        horizontalLayout->addLayout(verticalLayout_2);


        retranslateUi(KkcDictWidget);

        QMetaObject::connectSlotsByName(KkcDictWidget);
    } // setupUi

    void retranslateUi(QWidget *KkcDictWidget)
    {
        KkcDictWidget->setWindowTitle(fcitx::tr2fcitx("Form", nullptr));
        addDictButton_->setText(QString());
        removeDictButton_->setText(QString());
        moveUpDictButton_->setText(QString());
        moveDownDictButton_->setText(QString());
        defaultDictButton_->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class KkcDictWidget: public Ui_KkcDictWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DICTWIDGET_H
