/********************************************************************************
** Form generated from reading UI file 'shortcutwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SHORTCUTWIDGET_H
#define UI_SHORTCUTWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <fcitxqti18nhelper.h>

QT_BEGIN_NAMESPACE

class Ui_KkcShortcutWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *ruleLabel_;
    QComboBox *ruleComboBox_;
    QHBoxLayout *horizontalLayout_2;
    QTableView *shortcutView_;
    QVBoxLayout *verticalLayout_3;
    QPushButton *addShortcutButton_;
    QPushButton *removeShortCutButton_;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *KkcShortcutWidget)
    {
        if (KkcShortcutWidget->objectName().isEmpty())
            KkcShortcutWidget->setObjectName("KkcShortcutWidget");
        KkcShortcutWidget->resize(640, 354);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KkcShortcutWidget->sizePolicy().hasHeightForWidth());
        KkcShortcutWidget->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(KkcShortcutWidget);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        ruleLabel_ = new QLabel(KkcShortcutWidget);
        ruleLabel_->setObjectName("ruleLabel_");

        horizontalLayout->addWidget(ruleLabel_);

        ruleComboBox_ = new QComboBox(KkcShortcutWidget);
        ruleComboBox_->setObjectName("ruleComboBox_");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ruleComboBox_->sizePolicy().hasHeightForWidth());
        ruleComboBox_->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(ruleComboBox_);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        shortcutView_ = new QTableView(KkcShortcutWidget);
        shortcutView_->setObjectName("shortcutView_");
        shortcutView_->setMinimumSize(QSize(500, 300));
        shortcutView_->setSelectionMode(QAbstractItemView::SingleSelection);
        shortcutView_->setSelectionBehavior(QAbstractItemView::SelectRows);
        shortcutView_->horizontalHeader()->setStretchLastSection(true);
        shortcutView_->verticalHeader()->setVisible(false);

        horizontalLayout_2->addWidget(shortcutView_);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        addShortcutButton_ = new QPushButton(KkcShortcutWidget);
        addShortcutButton_->setObjectName("addShortcutButton_");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        addShortcutButton_->setIcon(icon);

        verticalLayout_3->addWidget(addShortcutButton_);

        removeShortCutButton_ = new QPushButton(KkcShortcutWidget);
        removeShortCutButton_->setObjectName("removeShortCutButton_");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        removeShortCutButton_->setIcon(icon1);

        verticalLayout_3->addWidget(removeShortCutButton_);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);


        horizontalLayout_2->addLayout(verticalLayout_3);


        verticalLayout->addLayout(horizontalLayout_2);

#if QT_CONFIG(shortcut)
        ruleLabel_->setBuddy(ruleComboBox_);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KkcShortcutWidget);

        QMetaObject::connectSlotsByName(KkcShortcutWidget);
    } // setupUi

    void retranslateUi(QWidget *KkcShortcutWidget)
    {
        KkcShortcutWidget->setWindowTitle(fcitx::tr2fcitx("Form", nullptr));
        ruleLabel_->setText(fcitx::tr2fcitx("R&ule:", nullptr));
        addShortcutButton_->setText(QString());
        removeShortCutButton_->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class KkcShortcutWidget: public Ui_KkcShortcutWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SHORTCUTWIDGET_H
